@@ -2,14 +2,15 @@ import unittest
 import os
 import glassdoor
 
-stdkeys = ['ceo', 'salary', 'satisfaction', 'connections']
+stdkeys = ['satisfaction', 'meta']
 
 class TestGD(unittest.TestCase):
 
     def test_getjson(self):
+        g = glassdoor.get('dropbox')
+        print g
         try:
-            gd = glassdoor.GETjson('dropbox')
-            self.assertTrue(all([k in gd.keys() for k in stdkeys]),
+            self.assertTrue(all([k in g.keys() for k in stdkeys]),
                             'Missing Keys')
         except Exception as e:
             raise Exception('GETjson failed: %s' % e)
